@@ -1,17 +1,39 @@
 """
-rumydata exception module
+Exception module
 
 This module contains specialized Exception classes which allow for aggregation
-of all errors identified in a subject.
-
-The majority of exceptions in this module are simple subclasses of the
-UrNotMyDataError exception, which do nothing except rename the class. These
-renames allow for more meaningful exception names to be associated with rules,
-and allow for more specific checking of particular errors (especially useful
-during testing).
+of all errors identified in a subject. These exceptions provide the structure to
+collect multiple exceptions at varying levels within a validation process, and
+display them in a meaningful way.
 """
 
 
+def debug():
+    """
+    Exception debug mode control
+
+    A switch to control exception message sanitation. This is a static
+    function which will always return False. In order to enable debug mode, you
+    must monkey patch this function using the mock library. This is made to
+    intentionally be inconvenient in order to prevent accidental disclosure of
+    data in exception logs through overuse of the debug mode.
+
+    This method is used at runtime by the base _check method. In order to enable
+    debugging, you must include a patch statement before calling a check. It is
+    recommended that you do this with a context handler to ensure appropriate
+    behavior of the patch.
+
+    example::
+
+        from unittest.mock import patch
+        from rumydata import field
+
+        with patch('rumydata.exception.debug', return_value=True):
+            field.Integer(1).check_cell(None)
+    """
+    return False
+
+
 class UrNotMyDataError(Exception):
     """
     Base exception class for rumydata package
@@ -79,12 +101,7 @@ class UrNotMyDataError(Exception):
 
         depth += 1
         for el in errors:
-            if isinstance(el, list) and not isinstance(el, (str, bytes)):
-                yield cls._flatten_md(el, depth)
-            elif issubclass(el.__class__, UrNotMyDataError):
-                yield el.md(depth)
-            else:
-                yield UrNotMyDataError(el)._md(depth)
+            yield el._md(depth)
 
 
 class FileError(UrNotMyDataError):
@@ -110,8 +127,15 @@ class ColumnError(UrNotMyDataError):
     :param errors: a list of errors contained in the column.
     """
 
-    def __init__(self, msg=None, errors: list = None):
-        super().__init__(msg, errors)
+    def __init__(self, index: int, msg=None, errors: list = None, **kwargs):
+        message = ''
+        offset = 0 if kwargs.get("zero_index") else 1
+
+        message += f'{str(index + offset)}'
+        if kwargs.get("name"):
+            message += f' ({kwargs.get("name")})'
+        message += f'; {msg}' if msg else ''
+        super().__init__(message, errors)
 
 
 class RowError(UrNotMyDataError):
@@ -159,93 +183,11 @@ class CellError(UrNotMyDataError):
         super().__init__(message, errors)
 
 
-class DataError(UrNotMyDataError):
-    pass
+class PreProcessingError(UrNotMyDataError):
+    """
+    Data Preprocessing Exception
 
-
-class DateFormatError(UrNotMyDataError):
-    pass
-
-
-class ConversionError(UrNotMyDataError):
-    pass
-
-
-class CurrencyPatternError(UrNotMyDataError):
-    pass
-
-
-class LengthError(UrNotMyDataError):
-    pass
-
-
-class LeadingZeroError(UrNotMyDataError):
-    pass
-
-
-class InvalidChoiceError(UrNotMyDataError):
-    pass
-
-
-class MissingColumnError(UrNotMyDataError):
-    pass
-
-
-class UnexpectedColumnError(UrNotMyDataError):
-    pass
-
-
-class DuplicateColumnError(UrNotMyDataError):
-    pass
-
-
-class RowLengthError(UrNotMyDataError):
-    pass
-
-
-class NotEnoughFieldsError(UrNotMyDataError):
-    pass
-
-
-class TooManyFieldsError(UrNotMyDataError):
-    pass
-
-
-class ValueComparisonError(UrNotMyDataError):
-    pass
-
-
-class FileUrNotMyDataError(UrNotMyDataError):
-    pass
-
-
-class FilePatternError(UrNotMyDataError):
-    pass
-
-
-class NullValueError(UrNotMyDataError):
-    _message = 'value is blank/null'
-
-
-class MaxExceededError(UrNotMyDataError):
-    pass
-
-
-class ColumnComparisonError(UrNotMyDataError):
-    pass
-
-
-class RowComparisonError(UrNotMyDataError):
-    pass
-
-
-class CharacterError(UrNotMyDataError):
-    pass
-
-
-class DuplicateValueError(UrNotMyDataError):
-    pass
-
-
-class NoRulesDefinedError(UrNotMyDataError):
-    pass
+    Thrown specifically when the data pre-processing step for a subject fails.
+    This is treated differently than the exceptions thrown by all fields, since
+    pre-processing exceptions prevent any further rules from being checked.
+    """
